CREATE TABLE IF NOT EXISTS [Alarms] (
  [username] VARCHAR(50) NOT NULL, 
  [device_id] INTEGER NOT NULL, 
  [pin] INT, 
  [value_object_name] VARCHAR(50) NOT NULL, 
  [low] REAL NOT NULL DEFAULT 0, 
  [high] REAL NOT NULL DEFAULT 0, 
  [digital_status] BOOLEAN NOT NULL DEFAULT false, 
  [alarm_active] BOOLEAN NOT NULL DEFAULT false, 
  [send_mail] BOOLEAN NOT NULL DEFAULT false, 
  [between_mail] INTEGER NOT NULL DEFAULT 5, 
  [alarm_value_counter] INTEGER DEFAULT 0, 
  [send_deactivate_mail_info] BOOLEAN, 
  [ok_time_min] INTEGER NOT NULL DEFAULT 1, 
  [mail_list] VARCHAR(100) DEFAULT empty, 
  [use_same_address] BOOLEAN, 
  [is_digital] BOOLEAN DEFAULT false, 
  [playnoksound] BOOLEAN NOT NULL DEFAULT false, 
  [sms_list] VARCHAR(255));


CREATE TABLE IF NOT EXISTS [Cfg_device] (
  [username] VARCHAR(50) NOT NULL DEFAULT 'local', 
  [device_id] INTEGER NOT NULL CONSTRAINT [UNIQUE] UNIQUE ON CONFLICT FAIL, 
  [device_name] VARCHAR(50) NOT NULL DEFAULT '<No named>', 
  [cb_insert_data] BOOLEAN NOT NULL DEFAULT 0, 
  [insert_from_serial] BOOLEAN DEFAULT 0, 
  [insert_from_ip] BOOLEAN DEFAULT 0, 
  [boardtype] VARCHAR, 
  [com] VARCHAR, 
  [hex] VARCHAR, 
  [data_com] VARCHAR, 
  [image] VARCHAR, 
  [last_load_prg] VARCHAR NOT NULL ON CONFLICT REPLACE DEFAULT 'main_prg', 
  [model] INT, 
  [ip] VARCHAR NOT NULL DEFAULT 'N/A', 
  [enablenotifications] BOOLEAN, 
  [maillist] VARCHAR, 
  [playnoksound] BOOLEAN NOT NULL DEFAULT false, 
  [smslist] VARCHAR(255), 
  [smsnotifications] BOOLEAN NOT NULL DEFAULT false);


CREATE TABLE IF NOT EXISTS [Components_cfg] (
  [username] VARCHAR(50) NOT NULL, 
  [device_id] INT NOT NULL, 
  [io] INT(10), 
  [prg_name] VARCHAR DEFAULT 'main_prg', 
  [pin] TINYINT(255) NOT NULL DEFAULT 1, 
  [byte1] TINYINT(255), 
  [byte2] TINYINT(255), 
  [byte3] TINYINT(255), 
  [byte4] TINYINT(255), 
  [top] INT NOT NULL DEFAULT 5, 
  [left] INT NOT NULL DEFAULT 5, 
  [cap_up] VARCHAR, 
  [cap_down] VARCHAR, 
  [rule] BLOB, 
  [anunit] CHAR, 
  [anshowtype] TINYINT(4), 
  [expression] VARCHAR, 
  [TimCntVal] INT DEFAULT 1, 
  [boolv1] BOOLEAN, 
  [write_to_db] BOOLEAN NOT NULL DEFAULT true, 
  [decimal_places] INT NOT NULL DEFAULT (-2), 
  [extra_array] BLOB);


CREATE TABLE IF NOT EXISTS [inputs_strings] (
  [username] VARCHAR(50) NOT NULL, 
  [device_id] INT NOT NULL, 
  [prg_name] VARCHAR DEFAULT 'main_prg', 
  [pin] TINYINT(255), 
  [in_type] TINYINT(255), 
  [in_index] TINYINT(255), 
  [in_name] VARCHAR, 
  [in_unit] VARCHAR, 
  [use_farenheit] BOOLEAN, 
  [is_tempsensor] BOOLEAN, 
  [description] VARCHAR, 
  [min] INT, 
  [max] INT, 
  [val_type] VARCHAR,
  [image_index] INT NOT NULL DEFAULT (-1));


CREATE TABLE IF NOT EXISTS [Last_data] (
  [datetime] REAL NOT NULL, 
  [username] VARCHAR(50) NOT NULL, 
  [device_id] INT NOT NULL, 
  [pin] TINYINT, 
  [byte2] TINYINT, 
  [byte3] TINYINT, 
  [byte4] TINYINT, 
  [byte5] TINYINT, 
  [val] FLOAT DEFAULT 0, 
  [is_received_from_serial] BOOLEAN DEFAULT 0, 
  [is_received_from_ip] BOOLEAN DEFAULT 0, 
  [IP] VARCHAR NOT NULL DEFAULT 'N/A', 
  [sec_between] INTEGER NOT NULL DEFAULT (-1), 
  [io] TINYINT DEFAULT 0, 
  [object_name] VARCHAR, 
  [alarm] BOOLEAN DEFAULT false);

CREATE TABLE IF NOT EXISTS [program] (
  [username] VARCHAR(50) NOT NULL DEFAULT 'local', 
  [device_id] INTEGER, 
  [description] VARCHAR, 
  [prg_name] VARCHAR NOT NULL DEFAULT 'main_prg', 
  [last_change] VARCHAR);

  
CREATE TABLE IF NOT EXISTS [Users_admin] (
  [username] VARCHAR(50) NOT NULL ON CONFLICT FAIL CONSTRAINT [unq_user] UNIQUE ON CONFLICT FAIL DEFAULT 'local', 
  [psw] VARCHAR(50) NOT NULL DEFAULT 'admin', 
  [full_description] VARCHAR(100), 
  [contact] VARCHAR(50) NOT NULL, 
  [email] VARCHAR(100) NOT NULL, 
  [phone] VARCHAR(100) NOT NULL, 
  [subscription_start] REAL, 
  [subscription_end] REAL, 
  [allow_access] BOOLEAN NOT NULL DEFAULT false);

  
CREATE TABLE IF NOT EXISTS[Users_web] (
  [login] VARCHAR(50) NOT NULL CONSTRAINT [UNIQUE] UNIQUE ON CONFLICT IGNORE, 
  [password] VARCHAR(200) NOT NULL, 
  [level] INTEGER NOT NULL DEFAULT 0);

CREATE TABLE IF NOT EXISTS [db_version_control] (
  [index_field] SMALLINT NOT NULL ON CONFLICT REPLACE CONSTRAINT [UNIQUE] UNIQUE ON CONFLICT REPLACE DEFAULT 1,
  [last_change] REAL NOT NULL DEFAULT 0,
  [db_version] INTEGER DEFAULT 1,
  [min_acc_version] FLOAT DEFAULT 1,
  [min_firmware_version] FLOAT DEFAULT 1);
  
  CREATE TABLE IF NOT EXISTS [mqtt_client] (
  [value_object] VARCHAR(30) NOT NULL CONSTRAINT [UNIQUE] UNIQUE ON CONFLICT REPLACE, 
  [device_id] INT NOT NULL, 
  [pin] TINYINT NOT NULL, 
  [topic] VARCHAR(100), 
  [value_name] VARCHAR, 
  [qos] TINYINT NOT NULL DEFAULT 0, 
  [retain] BOOLEAN NOT NULL DEFAULT false, 
  [publish] BOOLEAN DEFAULT false, 
  [onlyifvaluechanged] BOOLEAN DEFAULT false);
  
  CREATE TABLE IF NOT EXISTS[mqtt_topic] (
  [topic] VARCHAR(100) NOT NULL ON CONFLICT REPLACE CONSTRAINT [UNIQUE] UNIQUE ON CONFLICT REPLACE);
  